from practicum import find_mcu_boards, McuBoard, PeriBoard
from flask import Flask,redirect,url_for
from apscheduler.schedulers.background import BackgroundScheduler
from apscheduler.triggers.interval import IntervalTrigger
import atexit
import time
from flask_cors import CORS, cross_origin

device = find_mcu_boards()
mcu = McuBoard(device[0])
board = PeriBoard(mcu)
Temp_Default = [0,35]
Soil_Default = [0,30]
Temp_Temperature = []
Temp_Soil = []
buzzerstate = [1]

app = Flask(__name__)
cor = CORS(app)

def data():
    Temperature = board.get_temperature()
    Soil_Moisture = 100 - int(board.get_soil_moisture())
    if (Temperature == 0):
        Temp_Temperature.append(Temp_Temperature[-1])
        Temperature = Temp_Temperature[-1]
    else:
        Temp_Temperature.append(Temperature)
        
    Temp_Soil.append(Soil_Moisture)
    if(len(Temp_Temperature) == 30):
        Temp_Temperature.pop(0)
        Temp_Soil.pop(0)
    if(((Temperature < Temp_Default[0] or Temperature > Temp_Default[1]) or (Soil_Moisture < Soil_Default[0] or Soil_Moisture > Soil_Default[1])) and buzzerstate[0] == 1):
        board.set_buzzer(1)
    else:
        board.set_buzzer(0)

# create schedule for printing time
scheduler = BackgroundScheduler()
scheduler.start()
scheduler.add_job(func=data,trigger=IntervalTrigger(seconds=2),id='getdata',name='dataeverytwosec',replace_existing=True)
# Shut down the scheduler when exiting the app
atexit.register(lambda: scheduler.shutdown())

@app.route('/main')
def index():
    return ("Practicum Project")

@app.route("/getdata",methods = ['GET'])
def getdat():
    return {"Temp": Temp_Temperature, "Soil_Moisture": Temp_Soil}

@app.route("/buzzer/<int:state>",methods = ['GET'])
def set_bz(state):
    buzzerstate.append(state)
    buzzerstate.pop(0)
    return "Success"

@app.route("/settingtemp/<int:tempindex>/<int:value>",methods = ['GET'])
def set_temp(tempindex,value):
    Temp_Default[tempindex] = value
    return "Success"

@app.route("/settingsoil/<int:soilindex>/<int:value>",methods = ['GET'])
def set_soil(soilindex,value):
    Soil_Default[soilindex] = value
    return "Success"

@app.route("/gettempinterval",methods = ['GET'])
def intervaltemp():
    return {"TempInterval": Temp_Default}

@app.route('/getsoilinterval',methods = ['GET'])
def intervalsoil():
    return {"SoilInterval": Soil_Default}

@app.route('/getbuzzerstatus',methods = ['GET'])
def buzzerstatus():
    return {"BuzzerStatus" : buzzerstate[0]}

if __name__ == '__main__':
    app.run(port=8000,host='0.0.0.0')
