#include "usbdrv.h"
#include "DHT.h"

#define RQ_Soil_Moisture 0
#define RQ_DHT 1
#define RQ_buzzer 2

DHT dht;
/* ------------------------------------------------------------------------- */
/* ----------------------------- USB interface ----------------------------- */
/* ------------------------------------------------------------------------- */
usbMsgLen_t usbFunctionSetup(uint8_t data[8])
{
    usbRequest_t *rq = (void *)data;

    /* declared as static so they stay valid when usbFunctionSetup returns */
    static uint16_t Soil_Moisture;
    static int8_t Temperature;
    uint8_t buzzer_state;

    if(rq->bRequest == RQ_buzzer)
    {
        uint8_t buzzer_val = rq->wValue.bytes[0];
        digitalWrite(PIN_PC2, buzzer_val);
        return 0;
    }
    else if(rq->bRequest == RQ_DHT)
    {
        Temperature = dht.getTemperature();
        usbMsgPtr = (int8_t*) &Temperature;
        return sizeof(Temperature);
    }
    else
    {
        Soil_Moisture = analogRead(PIN_PC0);
        usbMsgPtr = (uint8_t*) &Soil_Moisture;
        return sizeof(Soil_Moisture);
    }

    /* default for not implemented requests: return no data back to host */
    return 0;
}

void setup()
{
    pinMode(PIN_PC0,INPUT);
    pinMode(PIN_PC1,INPUT);
    pinMode(PIN_PC2,OUTPUT);

    Serial.begin(9600);
    dht.setup(PIN_PC1);
    usbInit();

    /* enforce re-enumeration of USB devices */
    usbDeviceDisconnect();
    delay(300);
    usbDeviceConnect();
}

//////////////////////////////////////////////////////////////////////
void loop()
{
  usbPoll();
}
